/* eslint-disable jsx-a11y/label-has-associated-control */
/* eslint-disable react/no-danger */
/* eslint-disable react-hooks/rules-of-hooks */
/* eslint-disable react/destructuring-assignment */
/* eslint-disable import/prefer-default-export */
/* eslint-disable react/react-in-jsx-scope */
/* eslint-disable no-undef */
import React, { useContext } from 'react';
import { translate } from 'gatsby-core-theme/src/helpers/getters';
import { Context } from 'gatsby-core-theme/src/context/MainProvider';
import styles from './fields.module.scss';
import { generatePlaceholderString } from '../../../../helpers/generators.mjs';

const getField = (field, handleChange, elements, state) => {
  const { type, id, translationKey, label, placeholder, ...props } = field;
  const { translations } = useContext(Context) || {};

  switch (type) {
    case 'textarea':
      return (
        <div className={styles.textareaGroup || ''}>
          <textarea
            name={id}
            id={id}
            placeholder={translate(translations, placeholder?.translationKey, placeholder?.label)}
            {...props}
            value={elements[id]}
            onChange={(e) => handleChange(e.target.name, e.target.value)}
            className={`${(!state.isValid && elements[id] === '' && styles.invalid) || ''}`}
          />
          {field.maxLength && <span>{`${elements[id].length}/${field.maxLength}`}</span>}
        </div>
      );
    case 'checkbox':
      return (
        <div className={styles.checkboxGroup || ''}>
          {field.options.map((option) => (
            <div key={option.id}>
              <input
                id={option.id}
                name={option.id}
                type={type}
                checked={elements[option.id] === 'true'}
                onChange={(e) => handleChange(e.target.name, e.target.checked.toString())}
                required={!!option?.required}
              />
              <label
                htmlFor={option.id}
                className={`${
                  (!state.isValid && !elements[option.id].length && styles.invalid) || ''
                }`}
                dangerouslySetInnerHTML={{
                  __html: generatePlaceholderString(
                    translate(translations, option.translationKey, option.label),
                    translations,
                    option?.link
                  ),
                }}
              />
            </div>
          ))}
        </div>
      );
    case 'radio':
      return (
        <div className={styles.radioGroup || ''}>
          {field.options.map((option) => (
            <div key={option.id}>
              <input
                id={option.id}
                name={id}
                type={type}
                checked={elements[id] === option.label}
                onChange={(e) => handleChange(e.target.name, option.label)}
              />
              <label
                key={option.id}
                htmlFor={option.id}
                className={`${(!state.isValid && elements[id] === '' && styles.invalid) || ''}`}
              >
                {translate(translations, option.translationKey, option.label)}
              </label>
            </div>
          ))}
        </div>
      );
    case 'select':
      return (
        <select
          id={id}
          aria-label={id}
          name={id}
          defaultValue={elements[id]}
          onChange={(e) => handleChange(e.target.name, e.target.value)}
          className={`${(!state.isValid && elements[id] === '' && styles.invalid) || ''}`}
        >
          {field.showDefault && (
            <option value="">
              {translate(translations, field.defaultTranslationKey, field.defaultLabel)}
            </option>
          )}
          {field.options.map((option) => (
            <option key={option.id} value={option.label}>
              {translate(translations, option.translationKey, option.label)}
            </option>
          ))}
        </select>
      );
    case 'range':
      return (
        <div className={styles.radioGroup || ''}>
          <input
            name={id}
            id={id}
            type={type}
            aria-describedby={id}
            {...props}
            value={elements[id]}
            onChange={(e) => handleChange(e.target.name, e.target.value)}
          />
          <div className={styles.rangeValues || ''}>
            <span>{field.min}</span>
            <span className={`${(!state.isValid && elements[id] === '' && styles.invalid) || ''}`}>
              {elements[id] || 'Selected Value'}
            </span>
            <span>{field.max}</span>
          </div>
        </div>
      );
    default:
      return (
        <input
          name={id}
          id={id}
          type={type}
          aria-describedby={id}
          placeholder={translate(translations, placeholder?.translationKey, placeholder?.label)}
          {...props}
          value={elements[id]}
          onChange={(e) => handleChange(e.target.name, e.target.value)}
          className={`${(!state.isValid && elements[id] === '' && styles.invalid) || ''}`}
        />
      );
  }
};

export default getField;
